"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.FileManagerContextSetup = void 0;
var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));
var _createFileManager = require("./createFileManager");
var _FileStorage = require("./storage/FileStorage");
var _error = _interopRequireDefault(require("@webiny/error"));
var _isInstallationPending = require("./cmsFileStorage/isInstallationPending");
var _createFileManagerPlugins = require("./cmsFileStorage/createFileManagerPlugins");
var _file = require("./cmsFileStorage/file.model");
var _CmsFilesStorage = require("./cmsFileStorage/CmsFilesStorage");
var _CmsModelModifier = require("./modelModifier/CmsModelModifier");
var _apiHeadlessCms = require("@webiny/api-headless-cms");
var _FilesPermissions = require("./createFileManager/permissions/FilesPermissions");
class FileManagerContextSetup {
  constructor(context) {
    (0, _defineProperty2.default)(this, "context", void 0);
    this.context = context;
  }
  async setupContext(storageOperations) {
    if (storageOperations.beforeInit) {
      await storageOperations.beforeInit(this.context);
    }
    const fileStorageOps = await this.context.security.withoutAuthorization(() => {
      return this.setupCmsStorageOperations(storageOperations.aliases);
    });
    if (fileStorageOps) {
      storageOperations.files = fileStorageOps;
    }
    const filesPermissions = new _FilesPermissions.FilesPermissions({
      getIdentity: this.context.security.getIdentity,
      getPermissions: () => this.context.security.getPermissions("fm.file"),
      fullAccessPermissionName: "fm.*"
    });
    return (0, _createFileManager.createFileManager)({
      storageOperations,
      filesPermissions,
      getTenantId: this.getTenantId.bind(this),
      getLocaleCode: this.getLocaleCode.bind(this),
      getIdentity: this.getIdentity.bind(this),
      getPermissions: this.getPermissions.bind(this),
      storage: new _FileStorage.FileStorage({
        context: this.context
      }),
      // TODO: maybe this is no longer necessary, as this wil be managed by CMS?
      WEBINY_VERSION: this.context.WEBINY_VERSION
    });
  }
  getLocaleCode() {
    const locale = this.context.i18n.getContentLocale();
    if (!locale) {
      throw new _error.default("Missing locale on context.i18n locale in File Manager API.", "LOCALE_ERROR");
    }
    return locale.code;
  }
  getIdentity() {
    return this.context.security.getIdentity();
  }
  getTenantId() {
    return this.context.tenancy.getCurrentTenant().id;
  }
  async getPermissions(name) {
    return this.context.security.getPermissions(name);
  }
  async setupCmsStorageOperations(aliases) {
    if ((0, _isInstallationPending.isInstallationPending)({
      tenancy: this.context.tenancy,
      i18n: this.context.i18n
    })) {
      console.log("Installation pending!");
      return;
    }

    // This registers code plugins (model group, models)
    const {
      groupPlugin,
      fileModelDefinition
    } = (0, _createFileManagerPlugins.createFileManagerPlugins)();
    const modelModifiers = this.context.plugins.byType(_CmsModelModifier.CmsModelModifierPlugin.type);
    for (const modifier of modelModifiers) {
      await modifier.modifyModel(fileModelDefinition);
    }

    // Finally, register all plugins
    this.context.plugins.register([groupPlugin, new _apiHeadlessCms.CmsModelPlugin(fileModelDefinition)]);

    // Now load the file model registered in the previous step
    const fileModel = await this.getModel(_file.FILE_MODEL_ID);

    // Overwrite the original `files` storage ops
    return await _CmsFilesStorage.CmsFilesStorage.create({
      fileModel,
      cms: this.context.cms,
      security: this.context.security,
      aliases
    });
  }
  async getModel(modelId) {
    const model = await this.context.cms.getModel(modelId);
    if (!model) {
      throw new _error.default({
        code: "MODEL_NOT_FOUND",
        message: `Content model "${modelId}" was not found!`
      });
    }
    return model;
  }
}
exports.FileManagerContextSetup = FileManagerContextSetup;